package
Version:
v0.2.6
Opens a new window with list of versions in this module.
Published: Apr 10, 2025
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type RedisConfig struct {
Host string `config:"REDIS_HOST" default:"localhost"`
Port int `config:"REDIS_PORT" default:"6379"`
Password config.Secret `config:"REDIS_PASSWORD" default:""`
Database int `config:"REDIS_DATABASE" default:"0"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.